@@ -1,6 +1,6 @@
 package WWW::Google::UserAgent;
 
-$WWW::Google::UserAgent::VERSION = '0.05';
+$WWW::Google::UserAgent::VERSION = '0.06';
 
 use 5.006;
 use Data::Dumper;
@@ -17,7 +17,7 @@ WWW::Google::UserAgent - Core library for Google API services.
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
@@ -77,7 +77,7 @@ sub post {
     @caller = caller(2) if $caller[3] eq '(eval)';
 
     unless ($response->{success}) {
-        WWW::Google::Exception->throw({
+        WWW::Google::UserAgent::Exception->throw({
             method      => $caller[3],
             message     => "request to API failed",
             code        => $response->{status},
